@@ -28,7 +28,6 @@ import contextlib
 import datetime
 import errno
 import functools
-import gc
 import io
 import os
 import pathlib
@@ -799,7 +798,6 @@ class SevenZipFile(contextlib.AbstractContextManager):
         del self.files
         del self.header
         del self.sig_header
-        gc.collect()
 
     @staticmethod
     def _make_file_info(target: pathlib.Path, arcname: Optional[str] = None, dereference=False) -> Dict[str, Any]:
